@@ -17,7 +17,8 @@ def test_FUNC_client_group_delete_WITH_valid_configuration_EXPECT_group_deleted(
     :return: No return.
     """
     # Ensure group exists.
-    retrieved_group = sdk_client.group.get(group.group_id)
+    retrieved_group = sdk_client.group.get(group.group_id)[group.group_id]
+
     assert retrieved_group.group_id == group.group_id
 
     # Delete the group.
@@ -28,4 +29,4 @@ def test_FUNC_client_group_delete_WITH_valid_configuration_EXPECT_group_deleted(
 
     # Try to get deleted group. Should fail.
     with pytest.raises(NotFoundError):
-        sdk_client.group.get(group_id=retrieved_group.group_id)
+        sdk_client.group.get(retrieved_group.group_id)
