@@ -20,7 +20,8 @@ def test_FUNC_client_user_delete_WITH_existing_user_EXPECT_user_deleted(
     :return: No return.
     """
     # Ensure user exists.
-    refreshed_user = sdk_client.user.get(user.user_id)
+    refreshed_user = sdk_client.user.get(user.user_id)[user.user_id]
+
     assert refreshed_user.user_id == user.user_id
 
     # Expect this to succeed.
